@@ -39,11 +39,13 @@ class ImageDescription:
             if image.mode != "RGB":
                 image = image.convert(mode="RGB")
             new_images.append(image)
+        print("Predicting Image Description")
         pixel_values = self.feature_extractor(images=new_images, return_tensors="pt").pixel_values
         pixel_values = pixel_values.to(self.device)
         output_ids = self.model.generate(pixel_values, **self.gen_kwargs)
         preds = self.tokenizer.batch_decode(output_ids, skip_special_tokens=True)
         preds = [pred.strip() for pred in preds]
+        print("Predicting Image Description - Done!")
         return preds
 
     def run(self):
@@ -79,5 +81,6 @@ def get_image_captioning_models():
         model.save_pretrained(models_dir)
         feature_extractor.save_pretrained(models_dir)
         tokenizer.save_pretrained(models_dir)
+        print("=> Downloading models - Done!")
 
     return model, feature_extractor, tokenizer
