@@ -24,16 +24,21 @@ class ImagesData:
         self.label_hanlder()
 
         self.is_colored = True if len(self.image_shape) > 2 else False
-        if self.is_colored:
-            self.images_to_show = np.transpose(self.images, (0, 2, 3, 1))
-        else:
-            self.images_to_show = np.transpose(self.images, (0, 1, 2))
+        self.images_to_show = None
+        self.image_to_show()
         self.images_train, self.labels_train, self.images_val, self.labels_val = self.split()
         if self.is_colored:
             print("Colored image")
         else:
             print("Grayscale image")
 
+    def image_to_show(self):
+        images = self.images.reshape((-1,) + self.image_shape)
+        if self.is_colored:
+            self.images_to_show = np.transpose(images, (0, 2, 3, 1))
+        else:
+            self.images_to_show = np.transpose(images, (0, 1, 2))
+
     def label_hanlder(self):
         if isinstance(self.labels, pd.DataFrame):
             self.labels = self.labels.to_numpy()
